pub enum FastPacketError {
Decode(JpegError),
UnsupportedSof(SofKind),
UnsupportedColorSpace(ColorSpace),
UnsupportedSampling,
UnsupportedComponentOrder,
MissingScan,
MissingQuantTable {
slot: u8,
},
MissingHuffmanTable {
kind: TableKind,
slot: u8,
},
EntropyMarkerUnsupported {
marker: u8,
},
TruncatedEntropy,
}Expand description
Error while building a backend fast-path JPEG packet.
Variants
Decode(JpegError)
Header or entropy decode failed.
UnsupportedSof(SofKind)
JPEG SOF kind is not supported by the fast path.
UnsupportedColorSpace(ColorSpace)
JPEG color space is not supported by the selected fast path.
UnsupportedSampling
JPEG component sampling does not match the selected fast path.
UnsupportedComponentOrder
Scan component order does not match SOF component order.
MissingScan
Stream does not contain a scan payload.
MissingQuantTable
Referenced quantization table is absent.
MissingHuffmanTable
Referenced Huffman table is absent.
EntropyMarkerUnsupported
Entropy payload contains a marker unsupported by the fast path.
TruncatedEntropy
Entropy payload ended before the packet could be built.