#[non_exhaustive]pub enum ProgressiveScanStateError {
DuplicateInitial {
previous_al: u8,
al: u8,
},
RefinementBeforeInitial {
ah: u8,
al: u8,
},
RefinementMismatch {
previous_al: u8,
ah: u8,
al: u8,
},
MissingInitialDc,
}Expand description
Cross-scan progressive coefficient-state violation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateInitial
An initial scan selected a coefficient that was already initialized.
Fields
RefinementBeforeInitial
A refinement scan selected a coefficient with no initial scan.
Fields
RefinementMismatch
A refinement scan skipped or repeated an approximation level.
Fields
MissingInitialDc
EOI or physical EOF arrived before an initial DC scan for the component.