#[non_exhaustive]pub enum ProgressiveScanTerminationError {
ResidualEobRun {
remaining: u32,
},
ExcessEntropy {
unread_bytes: usize,
unread_bits: u8,
},
InvalidPadding {
unread_bits: u8,
},
TerminalMismatch {
expected_offset: usize,
expected_marker: Option<u8>,
found_offset: Option<usize>,
found_marker: Option<u8>,
},
}Expand description
Entropy condition that made a progressive scan terminator invalid.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ResidualEobRun
An EOB run extends beyond the final coded block in the scan.
ExcessEntropy
Complete entropy bytes or too many buffered bits remain after decoding.
Fields
InvalidPadding
The final partial entropy byte is not padded exclusively with one bits.
TerminalMismatch
The entropy reader observed a different boundary than the parser.
Fields