#[non_exhaustive]pub enum Warning {
MissingEoi,
SofDimensionsPatched {
from: (u16, u16),
to: (u16, u16),
},
NonstandardTables,
AdobeApp14Ambiguous {
raw_transform: u8,
},
IccProfileIgnored {
size: usize,
},
UnknownAppMarker {
marker: u8,
size: usize,
},
RestartRecovered {
offset: usize,
},
PrecisionClamped {
from_bits: u8,
to_bits: u8,
},
UnknownColorProfile,
TableCacheMismatch {
which: TableKind,
id: u8,
},
}Expand description
Non-fatal notices emitted during decode. See spec Section 6.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingEoi
Stream ended without an EOI marker after otherwise decodable entropy.
SofDimensionsPatched
SOF dimensions were repaired from external context.
NonstandardTables
Stream uses nonstandard but decodable table layout.
AdobeApp14Ambiguous
Adobe APP14 transform value could not unambiguously define color.
IccProfileIgnored
ICC profile was present but ignored by this decoder.
UnknownAppMarker
Unknown APP marker was skipped.
RestartRecovered
Decoder recovered at a restart marker.
PrecisionClamped
Higher-precision samples were clamped to a lower output precision.
UnknownColorProfile
Color profile metadata was present but unrecognized.
TableCacheMismatch
Cached table metadata disagreed with the active stream tables.